# heteroverlap
This project is used for regression-based heterogeneity analysis to identify overlapping subgroup structure in high-dimensional data. For more details, please check our paper.

## Installation
1) Install the package from pypi or
    ```
    pip install heteroverlap
    ```   
2) from source
    ```
    git clone https://github.com/foliag/subgroup
    cd subgroup
    pip install .
    ```       


## License & citation

The content of this repository is released under the terms of the [MIT license](LICENCE.txt).
Please consider citing our paper if you use it.

```
@article{luo2022regression,
author = {Luo, Ziye and Yao, Xinyue and Sun, Yifan and Fan, Xinyan},
title = {Regression-based heterogeneity analysis to identify overlapping subgroup structure in high-dimensional data},
journal = {Biometrical Journal},
volume = {n/a},
number = {n/a},
pages = {},
keywords = {heterogeneity analysis, high-dimensional data, overlapping subgroup structure, penalization, regression},
doi = {https://doi.org/10.1002/bimj.202100119},
url = {https://onlinelibrary.wiley.com/doi/abs/10.1002/bimj.202100119},
eprint = {https://onlinelibrary.wiley.com/doi/pdf/10.1002/bimj.202100119}
}
```




